==> haskell-tasty-hunit-0.10.2-129.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hunit
version:              0.10.2
visibility:           public
id:                   tasty-hunit-0.10.2-D3oxtfHDuWhFnpzpJ1XTpM
key:                  tasty-hunit-0.10.2-D3oxtfHDuWhFnpzpJ1XTpM
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.

    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.

category:             Testing
abi:                  7698f32eb986f17d3764db62e442fa07
exposed:              True
exposed-modules:      Test.Tasty.HUnit
hidden-modules:       Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/tasty-hunit-0.10.2
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/tasty-hunit-0.10.2
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/tasty-hunit-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hunit
hs-libraries:         HStasty-hunit-0.10.2-D3oxtfHDuWhFnpzpJ1XTpM
depends:
    base-4.18.3.0 call-stack-0.4.0-CNBVTySS9dB7ZkKYIwNNi0
    tasty-1.5.2-DYWdVUlVmZ2GEsYE1QJgVb

haddock-interfaces:   /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hunit-0.10.2-129.3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hunit
version:              0.10.2
visibility:           public
id:                   tasty-hunit-0.10.2-EWBbmTGIprlIBgm72wWDKr
key:                  tasty-hunit-0.10.2-EWBbmTGIprlIBgm72wWDKr
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.

    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.

category:             Testing
abi:                  ce00fc38afef79846bcf96b5eb68766b
exposed:              True
exposed-modules:      Test.Tasty.HUnit
hidden-modules:       Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/tasty-hunit-0.10.2
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/tasty-hunit-0.10.2
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/tasty-hunit-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hunit
hs-libraries:         HStasty-hunit-0.10.2-EWBbmTGIprlIBgm72wWDKr
depends:
    base-4.18.3.0 call-stack-0.4.0-CNBVTySS9dB7ZkKYIwNNi0
    tasty-1.5.2-1URN3hwk0ElEsqpxhMRHaT

haddock-interfaces:   /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
